<?xml version="1.0"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/TR/WD-xsl"
  result-ns="http://www.w3.org/TR/REC-html">

<--
    This XSL style sheet [based on WD-xsl-19981216] takes an iPAM product converted
    XML document (created via a ForwardAsXML filter) and produces an HTML table.
    See agent documenation for DTD.

*** Note that this uses ECMAScript and will only work with XSLP
*** using the FESI scripting extension.

-->

<xsl:script><![CDATA[
  var columnNames = new Object();
  var l = "%leftOpenBracket";
  var r = "%rightCloseBracket";

  function getRowValues(element) {
    var rowValues = new Object();
		var nodeList = element.getChildNodes();
    var nodeNum = nodeList.getLength();
		var s = "";

    for(var i=0; i < nodeNum; i++) {
      var node = nodeList.item(i);

      if(node.getNodeName() == "Property") {
        // get name attribute to find position
        var atts = node.getAttributes();
        var attrNameVal = atts.getNamedItem("name");

        // loop through each of its VALUES
        var childNodeList = node.getChildNodes();
        var childNodeNum = childNodeList.getLength();

        for(var t=0; t<childNodeNum; t++) {
          var node1 = childNodeList.item(t);

          if(node1.getNodeName() == "Value") {
            var child = node1.getFirstChild();
            rowValues[attrNameVal.getNodeValue()] = child.getData();
            //s = s + " " + attrNameVal.getNodeValue() + ":" + child.getData();
          }
        }
      }
    }

    for(var q=0; q<columnNames.length; q++) {
      var columnName = columnNames[q];
      var rowValue = rowValues[columnName];
      s = s + l + "TD" + r + rowValue + l + "/TD" + r;
    }

		return s;
  }

  function getColumnNames(element) {
    var nodeList = element.getChildNodes();
    var nodeNum = nodeList.getLength();
    var s = "";
    var j = 0;

    for(var i=0; i < nodeNum; i++) {
      var node = nodeList.item(i);

      if(node.getNodeName() == "Value") { // TxtElement
        var child = node.getFirstChild();
        var name = child.getData();
        columnNames[j++] = name;
        columnNames.length = j;
        s = s + l + "TH" + r + name + l + "/TH" + r;
      }
    }

    return s;
  }

  function processThingy(element) {
    var nodeList = element.getChildNodes();
    var nodeNum = nodeList.getLength();

    for(var i=0; i<nodeNum; i++) {
      var node = nodeList.item(i);

      if(node.getNodeName() == "Property") {
        var atts = node.getAttributes();
        var attrNameVal = atts.getNamedItem("name");

        if(attrNameVal.getNodeValue() == "knownContentProperties") {
          var s = getColumnNames(node);
          var t = getRowValues(element);
          return l + "TR" + r + s + l + "/TR" + r + "\n" + l + "TR" + r + t + l + "/TR" + r + "\n";
        }
      }
    }
  }
]]>
</xsl:script>

<xsl:template match="/">
  <HTML>
    <HEAD>
      <TITLE>Product Structure</TITLE>
    </HEAD>
    <BODY>
      <xsl:apply-templates/>
    </BODY>
  </HTML>
</xsl:template>

<xsl:template match="/Container">
  <!-- <TABLE border="1" bordercolor="blue" bordercolorlight="lightblue" bordercolordark="darkblue" cellspacing="3" cellpadding="2"> -->
  <TABLE border="1" cellspacing="3" cellpadding="2">
    <TR>
      <TH>
        <xsl:value-of select="Property[@name='id']">
        </xsl:value-of>
      </TH>
    </TR>
    <xsl:apply-templates/>
  </TABLE>
</xsl:template>

<xsl:template match="Container/Container">
  <TR>
    <TD>
      <!-- <TABLE border="1" bordercolor="blue" bordercolorlight="lightblue" bordercolordark="darkblue" cellspacing="3" cellpadding="2"> -->
      <TABLE border="1" cellspacing="3" cellpadding="2">
        <TR>
          <TH>
            <xsl:value-of select="Property[@name='id']">
            </xsl:value-of>
          </TH>
        </TR>
        <xsl:apply-templates/>
      </TABLE>
    </TD>
  </TR>
</xsl:template>

<xsl:template match="Container/Property[@name='knownContentProperties']">
  <TR>
    <xsl:script>getColumnNames(this);</xsl:script>
  </TR>
</xsl:template>

<xsl:template match="Container/Content">
  <TR>
    <xsl:script>getRowValues(this);</xsl:script>
  </TR>
</xsl:template>

<xsl:template match="Property">
</xsl:template>

<xsl:template match="Content">
  <TABLE border="1">
    <TR>
      <TH>
        <xsl:value-of select="Property[@name='id']">
        </xsl:value-of>
      </TH>
    </TR>
    <xsl:for-each select="Property">
      <TR>
        <TH><xsl:value-of select="@name"/></TH>
        <TD>
          <xsl:apply-templates/>
        </TD>
      </TR>
    </xsl:for-each>
  </TABLE>
</xsl:template>

</xsl:stylesheet>
